@@ -3,7 +3,11 @@ package Meow;
 use 5.006;
 use strict;
 use warnings;
-our $VERSION = '0.17';
+our $VERSION = '0.18';
+
+# Store specs for use after JIT compilation (for inheritance)
+# This is accessed from XS via get_hv("Meow::SPECS", ...)
+our %SPECS;
 
 require XSLoader;
 XSLoader::load('Meow', $VERSION);
@@ -20,7 +24,7 @@ Meow - Object ฅ^•ﻌ•^ฅ Orientation
 
 =head1 VERSION
 
-Version 0.17
+Version 0.18
 
 =cut
 
@@ -218,7 +222,7 @@ Constructs a new object, applying defaults, coercions, triggers, and builders as
 	}
 
 
-	my $r = timethese(10000000, {
+	my $r = timethese(5000000, {
 		'Moo' => sub {
 			my $foo = Foo::Extends::Moo->new();
 			$foo->one;
@@ -245,19 +249,28 @@ Constructs a new object, applying defaults, coercions, triggers, and builders as
 
 ...
 
-	Benchmark: timing 10,000,000 iterations of Marlin, Meow, Moo, Mouse...
-	    Marlin:  1 wallclock secs ( 2.17 usr +  0.05 sys =  2.22 CPU) @ 4504504.50/s (n=10000000)
-	      Meow:  5 wallclock secs ( 4.51 usr +  0.07 sys =  4.58 CPU) @ 2183406.11/s (n=10000000)
-	       Moo: 10 wallclock secs (11.47 usr +  0.04 sys = 11.51 CPU) @ 868809.73/s (n=10000000)
-	     Mouse:  5 wallclock secs ( 6.13 usr +  0.02 sys =  6.15 CPU) @ 1626016.26/s (n=10000000)
-		    Rate    Moo  Mouse   Meow Marlin
-	Moo     868810/s     --   -47%   -60%   -81%
-	Mouse  1626016/s    87%     --   -26%   -64%
-	Meow   2183406/s   151%    34%     --   -52%
-	Marlin 4504505/s   418%   177%   106%     --
+	Benchmark: timing 5000000 iterations of Cor, Marlin, Meow, Moo, Mouse...
+	       Cor:  0 wallclock secs ( 1.72 usr +  0.00 sys =  1.72 CPU) @ 2906976.74/s (n=5000000)
+	    Marlin:  0 wallclock secs ( 1.06 usr +  0.02 sys =  1.08 CPU) @ 4629629.63/s (n=5000000)
+	      Meow:  1 wallclock secs ( 1.08 usr +  0.00 sys =  1.08 CPU) @ 4629629.63/s (n=5000000)
+	       Moo:  6 wallclock secs ( 5.79 usr +  0.03 sys =  5.82 CPU) @ 859106.53/s (n=5000000)
+	     Mouse:  4 wallclock secs ( 3.12 usr +  0.01 sys =  3.13 CPU) @ 1597444.09/s (n=5000000)
+		    Rate    Moo  Mouse    Cor Marlin   Meow
+	Moo     859107/s     --   -46%   -70%   -81%   -81%
+	Mouse  1597444/s    86%     --   -45%   -65%   -65%
+	Cor    2906977/s   238%    82%     --   -37%   -37%
+	Marlin 4629630/s   439%   190%    59%     --    -0%
+	Meow   4629630/s   439%   190%    59%     0%     --
 
 Note: Type::Tiny::XS is installed and so is the other optional XS dependancies for Moo.
 
+The limitation is now my hardware with Marlin and Meow.
+
+	Benchmark: running Cor, Marlin, Meow for at least 5 CPU seconds...
+	       Cor:  5 wallclock secs ( 5.13 usr +  0.02 sys =  5.15 CPU) @ 2886788.16/s (n=14866959)
+	    Marlin:  5 wallclock secs ( 5.01 usr +  0.11 sys =  5.12 CPU) @ 4523074.80/s (n=23158143)
+	      Meow:  5 wallclock secs ( 5.16 usr +  0.02 sys =  5.18 CPU) @ 4558344.59/s (n=23612225)
+
 =head1 AUTHOR
 
 LNATION, C<< <email at lnation.org> >>
